-- Filename:     multinor.vhd
-- Filetype:     VHDL code
-- Date:         10 januari 2003
-- Update:       20 februari 2012
-- Description:  Een NOR met meerdere ingangen
-- Author:       J. op den Brouw
-- State:        demo
-- Error:        -
-- Version:      1.2
-- Copyright:    (c)2003-2012, De Haagse Hogeschool
--
-- Dit is een NOR met meerdere ingangen. Dat is op zich
-- niet zo vreemd, maar deze heeft een door de gebruiker
-- in te stellen breedte. Door middel een for .. loop worden de
-- ingangen een voor een afgetast.
-- Noot: merk op dat hier gebruik gemaakt wordt van een zogenaamde
-- generic. Bij instantiering van deze component in een hogere
-- hierarchie wordt default 8 bits gebruik, maar dit kan aangepast
-- worden m.b.v een generic map statement.

-- Gebruik IEEE std_logic_1164
library ieee;
use ieee.std_logic_1164.all;

-- Entity van de multinor
entity multinor is
    generic (tpd : time := 2 ns;
				 n : natural := 8);
    port (
        x : in std_logic_vector(n-1 downto 0);
        q : out std_logic
    );
end multinor;

architecture cascode of multinor is
begin
    P0: process (x) is
    -- tijdelijke opslag d.m.v. een variabele
    variable p : std_logic;
    begin
        -- p eerst op 0
        p := '0';
        -- wandel langs alle inputs van x
        for i in n-1 downto 0 loop
				-- doe een logische OR
            p := p or x(i);
        end loop;
        -- hierboven is een OR dus nu inverteren
        q <= not p after tpd;
    end process P0;
end cascode;
